--- /root/nginx-1.3.10/src/http/ngx_http_variables.c	2012-12-17 19:03:33.000000000 +0000
+++ /root/ngx_openresty-1.2.4.14/bundle/nginx-1.2.4/src/http/ngx_http_variables.c	2013-01-04 12:51:02.254569935 +0000
@@ -83,8 +83,16 @@
     ngx_http_variable_value_t *v, uintptr_t data);
 static ngx_int_t ngx_http_variable_request_time(ngx_http_request_t *r,
     ngx_http_variable_value_t *v, uintptr_t data);
+static ngx_int_t ngx_http_variable_request_length(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data);
+static ngx_int_t ngx_http_variable_pipe(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data);
 static ngx_int_t ngx_http_variable_status(ngx_http_request_t *r,
     ngx_http_variable_value_t *v, uintptr_t data);
+static ngx_int_t ngx_http_variable_time_iso8601(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data);
+static ngx_int_t ngx_http_variable_time_local(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data);
 
 static ngx_int_t ngx_http_variable_sent_content_type(ngx_http_request_t *r,
     ngx_http_variable_value_t *v, uintptr_t data);
@@ -245,10 +253,24 @@
 
     { ngx_string("request_time"), NULL, ngx_http_variable_request_time,
       0, NGX_HTTP_VAR_NOCACHEABLE, 0 },
+    
+    { ngx_string("request_length"), NULL, ngx_http_variable_request_length,
+      0, NGX_HTTP_VAR_NOCACHEABLE, 0 },
+    
+    { ngx_string("pipe"), NULL, ngx_http_variable_pipe,
+      0, NGX_HTTP_VAR_NOCACHEABLE, 0 },
 
     { ngx_string("status"), NULL,
       ngx_http_variable_status, 0,
       NGX_HTTP_VAR_NOCACHEABLE, 0 },
+    
+    { ngx_string("time_iso8601"), NULL,
+      ngx_http_variable_time_iso8601, 0,
+      NGX_HTTP_VAR_NOCACHEABLE, 0 },
+    
+    { ngx_string("time_local"), NULL,
+      ngx_http_variable_time_local, 0,
+      NGX_HTTP_VAR_NOCACHEABLE, 0 },
 
     { ngx_string("sent_http_content_type"), NULL,
       ngx_http_variable_sent_content_type, 0, 0, 0 },
@@ -1554,6 +1576,29 @@
     return NGX_OK;
 }
 
+static ngx_int_t
+ngx_http_variable_pipe(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data)
+{
+    u_char  *p;
+
+    v->data = ngx_pnalloc(r->pool, 1);
+    if (v->data == NULL) {
+        return NGX_ERROR;
+    }
+
+    if (r->pipeline) {
+        v->len = ngx_sprintf(v->data, "%c", 'p') - v->data;
+    } else {
+        v->len = ngx_sprintf(v->data, "%c", '.') - v->data;
+    }
+
+    v->valid = 1;
+    v->no_cacheable = 0;
+    v->not_found = 0;
+
+    return NGX_OK;
+}
 
 static ngx_int_t
 ngx_http_variable_status(ngx_http_request_t *r,
@@ -1587,6 +1632,45 @@
     return NGX_OK;
 }
 
+static ngx_int_t
+ngx_http_variable_time_iso8601(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data)
+{
+    v->data = ngx_pnalloc(r->pool, ngx_cached_http_log_iso8601.len);
+    if (v->data == NULL) {
+        return NGX_ERROR;
+    }
+
+    ngx_cpymem(v->data, ngx_cached_http_log_iso8601.data,
+                      ngx_cached_http_log_iso8601.len);
+
+    v->len = ngx_cached_http_log_iso8601.len;
+    v->valid = 1;
+    v->no_cacheable = 0;
+    v->not_found = 0;
+
+    return NGX_OK;
+}
+
+static ngx_int_t
+ngx_http_variable_time_local(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data)
+{
+    v->data = ngx_pnalloc(r->pool, ngx_cached_http_log_time.len);
+    if (v->data == NULL) {
+        return NGX_ERROR;
+    }
+
+    ngx_cpymem(v->data, ngx_cached_http_log_time.data,
+               ngx_cached_http_log_time.len);
+
+    v->len = ngx_cached_http_log_time.len;
+    v->valid = 1;
+    v->no_cacheable = 0;
+    v->not_found = 0;
+
+    return NGX_OK;
+}
 
 static ngx_int_t
 ngx_http_variable_sent_content_type(ngx_http_request_t *r,
@@ -1917,6 +2001,25 @@
     return NGX_OK;
 }
 
+static ngx_int_t
+ngx_http_variable_request_length(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data)
+{
+    u_char *p;
+
+    p = ngx_pnalloc(r->pool, NGX_OFF_T_LEN);
+    if (p == NULL) {
+        return NGX_ERROR;
+    }
+
+    v->len = ngx_sprintf(p, "%O", r->request_length) - p;
+    v->valid = 1;
+    v->no_cacheable = 0;
+    v->not_found = 0;
+    v->data = p;
+
+    return NGX_OK;
+}
 
 static ngx_int_t
 ngx_http_variable_connection(ngx_http_request_t *r,
